@@ -723,6 +723,7 @@ def bronze_to_silver(
                             'last_update',
                             'create_date',
                             'table_url',
+                            'layer'
                         ]
                 values = [
                         (
@@ -737,7 +738,8 @@ def bronze_to_silver(
                             tbl_properties.get('cortex.rowsCount'),
                             tbl_properties.get('cortex.lastUpdate'),
                             tbl_properties.get('cortex.createDate'),
-                            get_link_table(catalog_name, 'silver', output_db_table)
+                            get_link_table(catalog_name, 'silver', output_db_table),
+                            'silver'
                         )
                     ]
                 df_governance = spark.createDataFrame(values, columns)
@@ -873,6 +875,7 @@ def silver_to_gold(
                             'create_date',
                             'exposures',
                             'table_url'
+                            'layer'
                         ]
                 values = [
                         (
@@ -888,7 +891,8 @@ def silver_to_gold(
                             tbl_properties.get('cortex.lastUpdate'),
                             tbl_properties.get('cortex.createDate'),
                             tbl_properties.get('cortex.exposures'),
-                            get_link_table(catalog_name, 'gold', output_db_table)
+                            get_link_table(catalog_name, 'gold', output_db_table),
+                            'gold'
                         )
                     ]
                 df_governance = spark.createDataFrame(values, columns)
